RESK_CONTROL_CHARS = {
    '\r': '\\r',  # Carriage Return
    '\n': '\\n',  # Line Feed
    '\t': '\\t',  # Tab
    '\b': '\\b',  # Backspace
    '\f': '\\f',  # Form Feed
    '\v': '\\v',  # Vertical Tab
    '\0': '\\0',  # Null character
}